<!--
https://pypi.org/project/readme-generator/
https://pypi.org/project/python-readme-generator/
-->

[![](https://img.shields.io/badge/OS-macOS-blue.svg?longCache=True)]()
[![](https://img.shields.io/badge/language-AppleScript-blue.svg?longCache=True)]()

#### Installation
```bash
$ [sudo] pip install mac-screensaver
```

#### Scripts usage
command|`usage`
-|-
`screensaver` |`usage: screensaver command [args]`
`screensaver-name` |`usage: screensaver-name`
`screensaver-names` |`usage: screensaver-names`
`screensaver-pid` |`usage: screensaver-pid`
`screensaver-start` |`usage: screensaver-start`
`screensaver-stop` |`usage: screensaver-stop`
`screensaver-wait` |`usage: screensaver-wait`

#### Examples
```bash
$ screensaver start
$ screensaver pid
1488
$ screensaver stop
```

```bash
$ screensaver name
iLifeSlideshows
$ screensaver names
Random
Flurry
Arabesque
Word of the Day
iTunes Artwork
Computer Name
Shell
FloatingMessage
iLifeSlideshows
```
wait while screensaver is active
```bash
$ screensaver start
$ screensaver wait
```

<p align="center">
    <a href="https://pypi.org/project/python-readme-generator/">python-readme-generator</a>
</p>